/*++

Copyright (c) 2009
Lysann Kessler, Stephanie Platz, Thomas Klingbeil, Philipp Tessenow, Frank Schlegel;
Michael Haupt, Michael Perscheid, Robert Hirschfeld;
Software Architecture Group, Hasso-Plattner-Institut, University of Potsdam, Germany

This software is published under MIT license.
It uses phidget library by Phidgets Inc. (http://phidgets.com).
See ../../../../license.pdf for more information.

Module Name:

	PhidgetCompTextLCD.c

Abstract:

	This file contains methods for a Phidget Component TextLCD which is a special
	TextDisplay. 
	A component TextLCD can belong to several phidgets e.g. the phidget TextLCD.
	Only if one of these phidgets is attached the component is useable.	Use
	phidget_GetDeviceClass(pointerToPhidget) to call the specific phidget methods
	in phidget21 API.

--*/

#include "PhidgetCompTextLCD.h"

//////////////////////////////////////////////////////////////////////////
// methods 

//
// Gets the current backlight state of a component TextLCD with the
// corresponding index. This is true when the backlight is on
// otherwise false.
// Use id to identify the owning phidget.
//
BOOL phidgetCompTextLCD_IsBacklightOn(PhidgetId id)
{
	BOOL bValue = FALSE;
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, bValue);

	switch(phidget_GetDeviceClass(pPhidget))
	{
	case PHIDCLASS_TEXTLCD:
		CPhidgetTextLCD_getBacklight( ((PhidgetTextLCD*) pPhidget)->handle, &bValue );
		break;

	default:
		IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompTextLCD_IsBacklightOn.", phidget_GetDeviceClass(pPhidget)));
	}

	return bValue > 0;
}

//
// Sets the backlight state of a component TextLCD with the corresponding
// index. Set to true if the backlight should be set (on).
// Use id to identify the owning phidget.
// Return TRUE if the setting succeeded, FALSE otherwise.
//
BOOL phidgetCompTextLCD_SetBacklightOn(PhidgetId id, int iState)
{
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, FALSE);

	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
	case PHIDCLASS_TEXTLCD:
		return CPhidgetTextLCD_setBacklight( ((PhidgetTextLCD*) pPhidget)->handle, iState ) == 0;

	default:
		IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompTextLCD_SetBacklightOn.", phidget_GetDeviceClass(pPhidget)));
		return FALSE;
	}
}

//
// Gets the current cursor visible state of a component TextLCD with the
// corresponding index. This is true when the cursor is visible
// otherwise false.
// Use id to identify the owning phidget.
//
BOOL phidgetCompTextLCD_IsCursorOn(PhidgetId id)
{
	BOOL bValue = FALSE;
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, bValue);
	
	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
		case PHIDCLASS_TEXTLCD:
			CPhidgetTextLCD_getCursorOn( ((PhidgetTextLCD*) pPhidget)->handle, &bValue );
			break;
			
		default:
			IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompTextLCD_IsCursorOn.", phidget_GetDeviceClass(pPhidget)));
	}
	
	return bValue > 0;
}

//
// Sets the cursor visible state of a component TextLCD with the
// corresponding index. Set to true if the curor should be visible.
// Use id to identify the owning phidget.
// Return TRUE if the setting succeeded, FALSE otherwise.
//
BOOL phidgetCompTextLCD_SetCursorOn(PhidgetId id, int iState)
{
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, FALSE);
	
	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
		case PHIDCLASS_TEXTLCD:
			return CPhidgetTextLCD_setCursorOn( ((PhidgetTextLCD*) pPhidget)->handle, iState ) == 0;
			
		default:
			IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompTextLCD_SetCursorOn.", phidget_GetDeviceClass(pPhidget)));
			return FALSE;
	}
}

//
// Gets the current cursur blink state of a component TextLCD with the
// corresponding index. This is true when the cursur is blinking
// otherwise false.
// Use id to identify the owning phidget.
//
BOOL phidgetCompTextLCD_IsCursorBlinking(PhidgetId id)
{
	BOOL bValue = FALSE;
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, bValue);
	
	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
		case PHIDCLASS_TEXTLCD:
			CPhidgetTextLCD_getCursorBlink( ((PhidgetTextLCD*) pPhidget)->handle, &bValue );
			break;
			
		default:
			IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompTextLCD_IsCursorBlinking.", phidget_GetDeviceClass(pPhidget)));
	}
	
	return bValue > 0;
}

//
// Sets the cursor blink state of a component TextLCD with the
// corresponding index. Set to true if the curor should be blinking.
// Use id to identify the owning phidget.
// Return TRUE if the setting succeeded, FALSE otherwise.
//
BOOL phidgetCompTextLCD_SetCursorBlinking(PhidgetId id, int iState)
{
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, FALSE);
	
	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
		case PHIDCLASS_TEXTLCD:
			return CPhidgetTextLCD_setCursorBlink( ((PhidgetTextLCD*) pPhidget)->handle, iState ) == 0;
			
		default:
			IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompTextLCD_SetCursorBlinking.", phidget_GetDeviceClass(pPhidget)));
			return FALSE;
	}
}

//
// Gets the current contras of a component TextLCD with the corresponding
// index. Use id to identify the owning phidget.
//
int phidgetCompTextLCD_GetContrast(PhidgetId id)
{
	int iValue = 0;
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, iValue);
	
	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
		case PHIDCLASS_TEXTLCD:
			CPhidgetTextLCD_getContrast( ((PhidgetTextLCD*) pPhidget)->handle, &iValue );
			break;
			
		default:
			IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompTextLCD_GetContrast.", phidget_GetDeviceClass(pPhidget)));
	}
	
	return iValue;
}

//
// Sets the contrast of a component TextLCD with the corresponding index.
// Use id to identify the owning phidget.
// Return TRUE if the setting succeeded, FALSE otherwise.
//
BOOL phidgetCompTextLCD_SetContrast(PhidgetId id, int iContrast)
{	
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, FALSE);
	
	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
		case PHIDCLASS_TEXTLCD:
			if(iContrast < 0 || iContrast > 255)
				return FALSE;
			return CPhidgetTextLCD_setContrast( ((PhidgetTextLCD*) pPhidget)->handle, iContrast ) == 0;
			
		default:
			IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompTextLCD_SetContrast.", phidget_GetDeviceClass(pPhidget)));
			return FALSE;
	}
}

BOOL phidgetCompTextLCD_SetCustomChar(PhidgetId id, int iIndex, int iUpper, int iLower)
{
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, FALSE);
	
	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
		case PHIDCLASS_TEXTLCD:
			if(iIndex < 8 || iIndex > 15)
				return FALSE;
			return CPhidgetTextLCD_setCustomCharacter( ((PhidgetTextLCD*) pPhidget)->handle, iIndex, iUpper, iLower) == EPHIDGET_OK;
			
		default:
			IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompTextLCD_SetCustomChar.", phidget_GetDeviceClass(pPhidget)));
			return FALSE;
	}
}
