/*++

Copyright (c) 2009
Lysann Kessler, Stephanie Platz, Thomas Klingbeil, Philipp Tessenow, Frank Schlegel;
Michael Haupt, Michael Perscheid, Robert Hirschfeld;
Software Architecture Group, Hasso-Plattner-Institut, University of Potsdam, Germany

This software is published under MIT license.
It uses phidget library by Phidgets Inc. (http://phidgets.com).
See ../../../../license.pdf for more information.

Module Name:

	PhidgetCompTextDisplay.c

Abstract:

	This file contains methods for a Phidget Component TextDisplay. 
	A component TextDisplay is an abstact super class of the Components TextLCD and
	TextLED.
	Use phidget_GetDeviceClass(pointerToPhidget) to call the specific
	phidget methods	in phidget21 API.

--*/

#include "PhidgetCompTextDisplay.h"

//////////////////////////////////////////////////////////////////////////
// methods

//
// Gets the number of rows supported by the component TextDisplay.
// Use id to identify the owning phidget.
//
int phidgetCompTextDisplay_RowCount(PhidgetId id)
{
	int iValue = 0;
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, iValue);

	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
	case PHIDCLASS_TEXTLCD:
		CPhidgetTextLCD_getRowCount( ((PhidgetTextLCD*) pPhidget)->handle, &iValue );
		break;

	default:
		IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompTextDisplay_RowCount.", phidget_GetDeviceClass(pPhidget)));
	}

	return iValue;
}

//
// Gets the number of columns supported by the component TextDisplay.
// Use id to identify the owning phidget.
//
int phidgetCompTextDisplay_ColumnCount(PhidgetId id)
{
	int iValue = 0;
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, iValue);
	
	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
		case PHIDCLASS_TEXTLCD:
			CPhidgetTextLCD_getColumnCount( ((PhidgetTextLCD*) pPhidget)->handle, &iValue );
			break;
			
		default:
			IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompTextDisplay_ColumnCount.", phidget_GetDeviceClass(pPhidget)));
	}
	
	return iValue;
}

//
// Sets a row on a component TextDisplay with the corresponding index.
// The text pcString is displayed in row iRow.
// Use id to identify the owning phidget.
// Return TRUE if the setting succeeded, FALSE otherwise.
//
BOOL phidgetCompTextLCD_DisplayString(PhidgetId id, int iRow, char* pcString, int iLength)
{
	BOOL result;
	char* pszString;
	
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, FALSE);
	
	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
		case PHIDCLASS_TEXTLCD:
			// convert the string to be zero terminated
			pszString = phidgetPlugin_ConvertToCString(pcString, iLength);
			// display
			result = CPhidgetTextLCD_setDisplayString( ((PhidgetTextLCD*) pPhidget)->handle, iRow, pszString ) == 0;
			// free memory allocated for string conversion
			phidgetPlugin_FreeCString(pszString);
			return result;
			
		default:
			IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompTextLCD_DisplayString.", phidget_GetDeviceClass(pPhidget)));
			return FALSE;
	}
}

//
// Sets a character on a component TextDisplay with the corresponding
// index. The character cChar is displayed in row iRow and column iColumn.
// Use id to identify the owning phidget.
// Return TRUE if the setting succeeded, FALSE otherwise.
//
BOOL phidgetCompTextLCD_DisplayCharacter(PhidgetId id, int iRow, int iColumn, char cChar)
{
	Phidget* pPhidget = phidgetPlugin_GetPhidgetFromId_ElseReturn(id, pPhidget, FALSE);
	
	//detect the phidget's type
	switch(phidget_GetDeviceClass(pPhidget))
	{
		case PHIDCLASS_TEXTLCD:
			return CPhidgetTextLCD_setDisplayCharacter( ((PhidgetTextLCD*) pPhidget)->handle, iRow, iColumn, cChar ) == 0;
			
		default:
			IF_DBG(SLog(SLOG_LEVEL_ERROR, "Wrong Phidget type %i in phidgetCompTextLCD_DisplayCharacter.", phidget_GetDeviceClass(pPhidget)));
			return FALSE;
	}
}
