/*++

Copyright (c) 2009
Lysann Kessler, Stephanie Platz, Thomas Klingbeil, Philipp Tessenow, Frank Schlegel;
Michael Haupt, Michael Perscheid, Robert Hirschfeld;
Software Architecture Group, Hasso-Plattner-Institut, University of Potsdam, Germany

This software is published under MIT license.
It uses phidget library by Phidgets Inc. (http://phidgets.com).
See ../../../../license.pdf for more information.

Module Name:

	PhidgetTextLCD.c

Abstract:

	This file contains Phidget TextLCD specific methods. A Phidget
	TextLCD has a component textLCD. Both modules - PhidgetCompTextLCD.c 
	and PhidgetTextLCD.c - inmplement all methods supplied by the
	phidget21 API for an TextLCD.

--*/

#include "PhidgetTextLCD.h"

//////////////////////////////////////////////////////////////////////////
// PhidgetTextLCD methods

/*++

Routine Description:

	This method creates an PhidgetTextLCD struct and allocates memory.
	To identify the phidgets type the deviceClass is set here.
	Additionally do common creational settings.

Arguments:

	None.

Return Value:

	Squeak VM identifier for the PhigdetId Object.

--*/
PhidgetId phidgetTextLCD_Create()
{
	// allocate memory for a PhidgetTextLCD structure
	PhidgetTextLCD* pPhidget = calloc(1, sizeof(PhidgetTextLCD));

	// initialise
	pPhidget->deviceClass = PHIDCLASS_TEXTLCD;
	phidgetTextLCD_ResetSemaphores(pPhidget);

	// get id and add to global list. return the id
	return phidget_Create((Phidget*)pPhidget);
}

//
//reset semaphores
//
void phidgetTextLCD_ResetSemaphores(PhidgetTextLCD *pPhidget)
{
	// TextLCD has no own semaphores. Just call the base class.
	phidget_ResetSemaphores((Phidget*)pPhidget);
}


/*++

Routine Description:

	This method is called while opening a phidget. The actuall specific
	phidget object will be created and the specific callbacks will be
	registered.

Arguments:

	pPhidget - pointer of the Phidget to open the hardware connection.

Return Value:

	TRUE if the operation succeeded, FALSE otherwise.

--*/
int phidgetTextLCD_Open(PhidgetTextLCD *pPhidget)
{
	if(pPhidget == NULL)
	{
		IF_DBG(SLog(SLOG_LEVEL_ERROR, "Null pointer given in phidgetTextLCD_Open for pPhidget."));
		return FALSE;
	}

	// create the PhidgetTextLCD object
	pPhidget->handle=0;
	CPhidgetTextLCD_create(&(pPhidget->handle));

	// do phidget common open operations
	phidget_Open_Base((Phidget *)pPhidget);
	return TRUE;
}
